<?php

namespace Drupal\advban\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure advban settings for this site.
 */
class AdvbanSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'advban_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'advban.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('advban.settings');

    $form['advban_expiry_durations'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Expiry time formats for blocked IP addresses'),
      '#default_value' => $config->get('expiry_durations'),
      '#description' => $this->t("Must be in a format that <a href='@strtotime'>PHP's strtotime function</a> can interpret.", [
        '@strtotime' => 'https://php.net/manual/function.strtotime.php',
      ]),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $arr_advban_expiry_durations = explode("\n", $form_state->getValue('advban_expiry_durations'));
    foreach ($arr_advban_expiry_durations as $duration) {
      if (!strtotime($duration)) {
        $form_state->setErrorByName('advban_expiry_durations', $this->t('Expiry time formats has wrong expiry time %duration.', ['%duration' => $duration]));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('advban.settings')
      ->set('expiry_durations', $form_state->getValue('advban_expiry_durations'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
